.. Copyright 2011, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Web framework
=============

.. toctree::
   :maxdepth: 2

   Core web framework functionality (reahl.web.fw) <fw>
   Widgets -- user interface elements (reahl.web.ui) <ui>
   Paging long lists (reahl.web.pager) <pager>
   Including not-quite-static static content (reahl.web.djhtml) <djhtml>
   Interfaces for persisted classes of which many implementations can exist (reahl.web.interfaces) <interfaces>




